@@ -5,6 +5,12 @@ This library provides sklearn-like estimators for causal inference
 using the difference-in-differences methodology.
 """
 
+from diff_diff.bacon import (
+    BaconDecomposition,
+    BaconDecompositionResults,
+    Comparison2x2,
+    bacon_decompose,
+)
 from diff_diff.diagnostics import (
     PlaceboTestResults,
     leave_one_out_test,
@@ -30,6 +36,22 @@ from diff_diff.honest_did import (
     compute_honest_did,
     sensitivity_plot,
 )
+from diff_diff.power import (
+    PowerAnalysis,
+    PowerResults,
+    SimulationPowerResults,
+    compute_mde,
+    compute_power,
+    compute_sample_size,
+    simulate_power,
+)
+from diff_diff.pretrends import (
+    PreTrendsPower,
+    PreTrendsPowerCurve,
+    PreTrendsPowerResults,
+    compute_mdv,
+    compute_pretrends_power,
+)
 from diff_diff.prep import (
     aggregate_to_cohorts,
     balance_panel,
@@ -51,8 +73,19 @@ from diff_diff.results import (
 from diff_diff.staggered import (
     CallawaySantAnna,
     CallawaySantAnnaResults,
+    CSBootstrapResults,
     GroupTimeEffect,
 )
+from diff_diff.sun_abraham import (
+    SABootstrapResults,
+    SunAbraham,
+    SunAbrahamResults,
+)
+from diff_diff.triple_diff import (
+    TripleDifference,
+    TripleDifferenceResults,
+    triple_difference,
+)
 from diff_diff.utils import (
     WildBootstrapResults,
     check_parallel_trends,
@@ -61,13 +94,16 @@ from diff_diff.utils import (
     wild_bootstrap_se,
 )
 from diff_diff.visualization import (
+    plot_bacon,
     plot_event_study,
     plot_group_effects,
     plot_honest_event_study,
+    plot_power_curve,
+    plot_pretrends_power,
     plot_sensitivity,
 )
 
-__version__ = "0.6.0"
+__version__ = "1.2.1"
 __all__ = [
     # Estimators
     "DifferenceInDifferences",
@@ -75,13 +111,26 @@ __all__ = [
     "MultiPeriodDiD",
     "SyntheticDiD",
     "CallawaySantAnna",
+    "SunAbraham",
+    "TripleDifference",
+    # Bacon Decomposition
+    "BaconDecomposition",
+    "BaconDecompositionResults",
+    "Comparison2x2",
+    "bacon_decompose",
+    "plot_bacon",
     # Results
     "DiDResults",
     "MultiPeriodDiDResults",
     "SyntheticDiDResults",
     "PeriodEffect",
     "CallawaySantAnnaResults",
+    "CSBootstrapResults",
     "GroupTimeEffect",
+    "SunAbrahamResults",
+    "SABootstrapResults",
+    "TripleDifferenceResults",
+    "triple_difference",
     # Visualization
     "plot_event_study",
     "plot_group_effects",
@@ -122,4 +171,20 @@ __all__ = [
     "DeltaSDRM",
     "compute_honest_did",
     "sensitivity_plot",
+    # Power analysis
+    "PowerAnalysis",
+    "PowerResults",
+    "SimulationPowerResults",
+    "compute_mde",
+    "compute_power",
+    "compute_sample_size",
+    "simulate_power",
+    "plot_power_curve",
+    # Pre-trends power analysis
+    "PreTrendsPower",
+    "PreTrendsPowerResults",
+    "PreTrendsPowerCurve",
+    "compute_pretrends_power",
+    "compute_mdv",
+    "plot_pretrends_power",
 ]
